============================================
Welcome to audioinfo's documentation!
============================================

audioinfo is an open-source multipurpose speech mixture simulator whose simulated dataset can cover speaker localization, tracking, dereverberation, enhancement, separation, and recognition tasks.

.. toctree::
  :caption: Getting started
  :maxdepth: 1
  :titlesonly:

  usage/overview.md
  usage/install.md
  usage/pipelines.md
  usage/config.rst
  usage/package_layout.md
  usage/ovr.md
  usage/configurable_output.rst
  usage/related.md

.. toctree::
  :caption: API documentation

  api/util

.. toctree::
  :caption: Reference
  :maxdepth: 1
  :titlesonly:

  reference/contributing.md
  reference/conduct.md
  reference/changelog.md


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`